==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/automation/kotlin/inputs/ScheduleAssociationPropertyArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.automation.kotlin.inputs

import com.pulumi.azurenative.automation.inputs.ScheduleAssociationPropertyArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * The schedule property associated with the entity.
 * @property name Gets or sets the name of the Schedule.
 */
public data class ScheduleAssociationPropertyArgs(
    public val name: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.automation.inputs.ScheduleAssociationPropertyArgs> {
    override fun toJava(): com.pulumi.azurenative.automation.inputs.ScheduleAssociationPropertyArgs =
        com.pulumi.azurenative.automation.inputs.ScheduleAssociationPropertyArgs.builder()
            .name(name?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [ScheduleAssociationPropertyArgs].
 */
@PulumiTagMarker
public class ScheduleAssociationPropertyArgsBuilder internal constructor() {
    private var name: Output<String>? = null

    /**
     * @param value Gets or sets the name of the Schedule.
     */
    @JvmName("enicgyraerxmkymc")
    public suspend fun name(`value`: Output<String>) {
        this.name = value
    }

    /**
     * @param value Gets or sets the name of the Schedule.
     */
    @JvmName("mfgokkvxqdnbssnq")
    public suspend fun name(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.name = mapped
    }

    internal fun build(): ScheduleAssociationPropertyArgs = ScheduleAssociationPropertyArgs(
        name = name,
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/automation/kotlin/inputs/ScheduleAssociationPropertyArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.automation.kotlin.inputs

import com.pulumi.azurenative.automation.inputs.ScheduleAssociationPropertyArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * The schedule property associated with the entity.
 * @property name Gets or sets the name of the Schedule.
 */
public data class ScheduleAssociationPropertyArgs(
    public val name: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.automation.inputs.ScheduleAssociationPropertyArgs> {
    override fun toJava(): com.pulumi.azurenative.automation.inputs.ScheduleAssociationPropertyArgs =
        com.pulumi.azurenative.automation.inputs.ScheduleAssociationPropertyArgs.builder()
            .name(name?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [ScheduleAssociationPropertyArgs].
 */
@PulumiTagMarker
public class ScheduleAssociationPropertyArgsBuilder internal constructor() {
    private var name: Output<String>? = null

    /**
     * @param value Gets or sets the name of the Schedule.
     */
    @JvmName("rkgkrodbyqjmlhom")
    public suspend fun name(`value`: Output<String>) {
        this.name = value
    }

    /**
     * @param value Gets or sets the name of the Schedule.
     */
    @JvmName("penoixqakypiungp")
    public suspend fun name(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.name = mapped
    }

    internal fun build(): ScheduleAssociationPropertyArgs = ScheduleAssociationPropertyArgs(
        name = name,
    )
}
